@@ -36,6 +36,14 @@ workspace_item_checkbox class in ul.workspace_items
 $("a.url-lizard-map-workspace-item-edit").attr("href");
 */
 
+
+function isCollagePopupVisible() {
+    return ($("#graph-popup-content div:first-child").length !== 0 &&
+            $("#graph-popup-content div:first-child").data("is_collage_popup") &&
+            $("#graph-popup").css("display") === "block");
+}
+
+
 jQuery.fn.liveCheckboxes = function () {
     return this.each(function () {
         var $workspace;
@@ -52,11 +60,26 @@ jQuery.fn.liveCheckboxes = function () {
                 async: false
             });
         });
+        $workspace.find(".snippet-checkbox").live('click', function () {
+            var url = $workspace.attr("data-url-lizard-map-snippet-edit");
+            $.ajax({
+                url: url,
+                data: { snippet_id: this.id, visible: this.checked },
+                success: function (snippet) {
+                    $workspace.updateWorkspace();
+                },
+                type: "POST",
+                async: false
+            });
+            // Reload the collage_popup if it is already visible
+            if (isCollagePopupVisible()) {
+                $(".collage").collagePopup();
+            }
+        });
     });
 };
 
 
-
 /* Shows an "jquery tools overlay" popup, data must have the following properties:
 data.html
 
@@ -128,6 +151,7 @@ function hover_popup(data, map) {
     }
 }
 
+
 jQuery.fn.collagePopup = function () {
     var url, collage_id;
     url = $(this).closest("[data-url-lizard-map-collage-popup]").attr("data-url-lizard-map-collage-popup");
@@ -137,10 +161,15 @@ jQuery.fn.collagePopup = function () {
         { collage_id: collage_id },
         function (data) {
             show_popup(data);
+            // Mark popup as being a collage popup
+            $("#graph-popup-content div:first-child").data("is_collage_popup", true);
+
         }
     );
+
 };
 
+
 /* Make workspaces sortable and droppable
 
 Needed: data attributes on the <div class="workspace">:
@@ -222,15 +251,7 @@ jQuery.fn.workspaceInteraction = function () {
         });
         // Make collage clickable. (DONE: should be collage-popup)
         $(".collage-popup", $workspace).live('click',
-                                       $(this).collagePopup);
-        // Snippets. Using sortable instead of draggable because
-        // Draggable applies to li and sortable applies to ul element
-        snippet_list = $workspace.find("ul.snippet-list");
-        snippet_list.sortable({
-            helper: 'clone',
-            items: 'li.snippet'
-        });
-
+                                       $(".collage").collagePopup);
         // Make checkboxes work.
         $workspace.liveCheckboxes();
         // Initialize the graph popup.
@@ -262,8 +283,13 @@ jQuery.fn.updateWorkspace = function () {
                     $('.map-actions', $holder).html());
                 $("#lizard-map-wms").html(
                     $('#lizard-map-wms', $holder).html());
+                $("#collage").html(
+                    $('#collage', $holder).html());
+                reloadGraphs();
                 // reload map layers
-                refreshLayers(); // from lizard_wms.js
+                if ($("#map").length > 0) {
+                    refreshLayers(); // from lizard_wms.js
+                }
                 // Is this enough? See also refreshMapActionsDivs in lizard_map
                 setUpAnimationSlider();
                 setUpTransparencySlider();
