@@ -2,7 +2,7 @@
 /*jslint browser: true */
 /*global $, OpenLayers, window, updateLayers, addProgressAnimationIntoWorkspace,
 stretchOneSidebarBox, reloadGraphs, fillSidebar, show_popup,
-hover_popup, layers, map, refreshLayers */
+hover_popup, layers, map, refreshLayers, isCollagePopupVisible */
 
 var animationTimer, transparencyTimer;
 
@@ -81,19 +81,22 @@ function setUpTransparencySlider() {
 
 function setUpMapLoadDefaultLocation() {
     $("#map-load-default-location").click(function () {
-        var url, coordinates, zoom;
+        var url;
         url = $(this).attr("data-url");
         $.getJSON(
             url, function (data) {
-                var extent;
+                var extent, zoom;
                 if (data.extent !== undefined) {
                     extent = new OpenLayers.Bounds(
                         data.extent.left,
-                        data.extent.top,
+                        data.extent.bottom,
                         data.extent.right,
-                        data.extent.bottom);
-                    map.setCenter(extent.getCenterLonLat(),
-                                  map.getZoomForExtent(extent) - 1);
+                        data.extent.top);
+                    // Don't decrease the zoom level here! If you want to see
+                    // a larger area in your viewport, you should define a
+                    // larger start_extent for your project. #2762
+                    zoom = map.getZoomForExtent(extent);
+                    map.setCenter(extent.getCenterLonLat(), zoom);
                 }
             });
     });
@@ -327,15 +330,20 @@ function setUpWorkspaceButtons() {
             { object_id: object_id },
             function () {
                 $workspace.updateWorkspace();
+                // Reload the collage_popup if it is already present
+                if (isCollagePopupVisible()) {
+                    $(".collage").collagePopup();
+                }
             });
         return false;
     });
-    // Make snippets clickable.
-    $("li.snippet").live('click', function (event) {
-        var $workspace, url, snippet_id;
+    // Make snippetnames clickable.
+    $("div.snippet-name").live('click', function (event) {
+        var $snippet, $workspace, url, snippet_id;
+        $snippet = $(this).parents("li.snippet");
         $workspace = $(this).parents("div.workspace");
         url = $workspace.attr("data-url-lizard-map-snippet-popup");
-        snippet_id = $(this).attr("data-object-id");
+        snippet_id = $snippet.attr("data-object-id");
         $.getJSON(
             url,
             { snippet_id: snippet_id },
@@ -549,7 +557,9 @@ function setUpWorkspaceItemPanToLayer() {
                         extent.west, extent.north,
                         extent.east, extent.south);
                     map.setCenter(ol_extent.getCenterLonLat(),
-                                  map.getZoomForExtent(ol_extent) - 3);
+                                  map.getZoomForExtent(ol_extent));
+                                  // map.getZoomForExtent(ol_extent) - 3);
+                                  // ^^^ - 3 was not nice in Deltaportaal
                 }
             });
     });
@@ -590,27 +600,29 @@ Sends current extent and name of visible base layer.
 function mapSaveLocation() {
     var url, extent, visible_base_layer_name, i;
     url = $("#lizard-map-wms").attr("data-save-location-url");
-    extent = map.getExtent();
-    visible_base_layer_name = "";
+    if ($("#map").length > 0) {
+        extent = map.getExtent();
+        visible_base_layer_name = "";
 
-    // Find the active base layer.
-    for (i = 0; i < map.layers.length; i = i + 1) {
-        if (map.layers[i].isBaseLayer && map.layers[i].visibility) {
-            visible_base_layer_name = map.layers[i].name;
-            break;
+        // Find the active base layer.
+        for (i = 0; i < map.layers.length; i = i + 1) {
+            if (map.layers[i].isBaseLayer && map.layers[i].visibility) {
+                visible_base_layer_name = map.layers[i].name;
+                break;
+            }
         }
+        $.ajax({
+            type: 'POST',
+            url: url,
+            data: {bottom: extent.bottom,
+                   left: extent.left,
+                   right: extent.right,
+                   top: extent.top,
+                   base_layer_name: visible_base_layer_name},
+            async: false,
+            success: function () {}
+        });
     }
-    $.ajax({
-        type: 'POST',
-        url: url,
-        data: {bottom: extent.bottom,
-               left: extent.left,
-               right: extent.right,
-               top: extent.top,
-               base_layer_name: visible_base_layer_name},
-        async: false,
-        success: function () {}
-    });
 }
 
 
