@@ -8,7 +8,6 @@ from lizard_map.views import CUSTOM_LEGENDS
 
 register = template.Library()
 
-
 @register.inclusion_tag("lizard_map/tag_workspace_debug.html",
                         takes_context=True)
 def workspace_debug_info(context):
@@ -98,6 +97,18 @@ def float_or_exp(value):
     """Show number with 2 decimals or with an exponent if too small."""
     return float_to_string(value)
 
+
+@register.inclusion_tag("lizard_map/tag_date_trigger.html",
+                        takes_context=True)
+def date_trigger(context):
+    """Displays date icon and link"""
+    return {
+        'date_range_form': context.get('date_range_form', None),
+        'date_start_period': context.get('date_start_period', None),
+        'date_end_period': context.get('date_end_period', None),
+        }
+
+
 @register.inclusion_tag("lizard_map/tag_date_popup.html",
                         takes_context=True)
 def date_popup(context):
