@@ -25,7 +25,6 @@ from lizard_map.models import WorkspaceCollageSnippetGroup
 from lizard_map.utility import analyze_http_user_agent
 from lizard_map.utility import short_string
 from lizard_map.workspace import WorkspaceManager
-
 # Workspace stuff
 
 CUSTOM_LEGENDS = 'custom_legends'
@@ -56,17 +55,15 @@ def homepage(request,
 
     return render_to_response(
         template,
-        {'javascript_hover_handler': 'popup_hover_handler',
-         'javascript_click_handler': 'popup_click_handler',
-         'crumbs': crumbs,
+        {'crumbs': crumbs,
          'application_screen_slug': application_screen_slug},
         context_instance=RequestContext(request))
 
 
 def workspace(request,
               workspace_id,
-              javascript_click_handler='popup_click_handler',
-              javascript_hover_handler='popup_hover_handler',
+              javascript_click_handler=None,
+              javascript_hover_handler=None,
               template='lizard_map/workspace.html'):
     """Render page with one workspace.
 
@@ -74,12 +71,15 @@ def workspace(request,
     """
     workspace = get_object_or_404(Workspace, pk=workspace_id)
 
+    context_dict = {'workspaces': {'user': [workspace]},
+                    }
+    if javascript_click_handler:
+        context_dict['javascript_click_handler'] = javascript_click_handler
+    if javascript_hover_handler:
+        context_dict['javascript_hover_handler'] = javascript_hover_handler
     return render_to_response(
         template,
-        {'workspaces': {'user': [workspace]},
-         'javascript_click_handler': javascript_click_handler,
-         'javascript_hover_handler': javascript_hover_handler,
-         },
+        context_dict,
         context_instance=RequestContext(request))
 
 
@@ -250,7 +250,7 @@ def snippet_group_image(request, snippet_group_id, legend=True):
 
     snippet_group = WorkspaceCollageSnippetGroup.objects.get(
         pk=snippet_group_id)
-    snippets = snippet_group.snippets.all()
+    snippets = snippet_group.snippets.filter(visible=True)
     identifiers = [snippet.identifier for snippet in snippets]
 
     # Add aggregation_period to each identifier
@@ -453,7 +453,8 @@ def popup_collage_json(collage, popup_id, request=None):
     """
 
     html = []
-    snippet_groups = collage.snippet_groups.all()
+    snippet_groups = collage.visible_snippet_groups()
+#    snippet_groups = collage.snippet_groups.all()
     if len(snippet_groups) > 1:
         big_popup = True
     else:
@@ -461,7 +462,7 @@ def popup_collage_json(collage, popup_id, request=None):
     google_x, google_y = None, None
 
     for snippet_group in snippet_groups:
-        snippets = snippet_group.snippets.all()
+        snippets = snippet_group.snippets.filter(visible=True)
         if snippets:
             # Pick workspace_item of first snippet to build html
             workspace_item = snippets[0].workspace_item
@@ -612,8 +613,13 @@ def collage_empty(request):
     TODO: check if workspace is actually yours
     """
     collage_id = request.POST.get('collage_id')
-    collage = get_object_or_404(WorkspaceCollage, pk=collage_id)
-    collage.delete()
+    snippetgroups = WorkspaceCollageSnippetGroup.objects.filter(
+        workspace_collage=collage_id)
+    for s in snippetgroups:
+        s.delete()
+
+#    collage = get_object_or_404(WorkspaceCollage, pk=collage_id)
+#    collage.delete()
 
     return HttpResponse("")
 
@@ -652,14 +658,22 @@ def workspace_item_image(request, workspace_item_id):
                                         layout_extra=layout_extra)
 
 
-def snippet_edit(request, snippet_id):
+@never_cache
+def snippet_edit(request, snippet_id=None, visible=None):
     """
     Edits snippet layout properties.
     """
-    snippet = WorkspaceCollageSnippet.objects.get(pk=snippet_id)
-
     post = request.POST
     layout = {}
+    if snippet_id is None:
+        snippet_id = post['snippet_id']
+    snippet = get_object_or_404(WorkspaceCollageSnippet, pk=snippet_id)
+    if visible is None:
+        if post['visible']:
+            visible = post['visible']
+    if visible:
+        lookup = {'true': True, 'false': False}
+        snippet.visible = lookup[visible]
     if post.get('color', None):
         layout.update({'color': post['color']})
     if post.__contains__('line_min'):
